@@ -1,21 +1,21 @@
-# -*- coding: utf-8 -*-
 """Node assortativity coefficients and correlation measures.
 """
-import networkx as nx
-from networkx.algorithms.assortativity.mixing import degree_mixing_matrix, \
-    attribute_mixing_matrix, numeric_mixing_matrix
-from networkx.algorithms.assortativity.pairs import node_degree_xy, \
-    node_attribute_xy
-__author__ = ' '.join(['Aric Hagberg <aric.hagberg@gmail.com>',
-                       'Oleguer Sagarra <oleguer.sagarra@gmail.com>'])
-__all__ = ['degree_pearson_correlation_coefficient',
-           'degree_assortativity_coefficient',
-           'attribute_assortativity_coefficient',
-           'numeric_assortativity_coefficient']
+from networkx.algorithms.assortativity.mixing import (
+    degree_mixing_matrix,
+    attribute_mixing_matrix,
+    numeric_mixing_matrix,
+)
+from networkx.algorithms.assortativity.pairs import node_degree_xy
+
+__all__ = [
+    "degree_pearson_correlation_coefficient",
+    "degree_assortativity_coefficient",
+    "attribute_assortativity_coefficient",
+    "numeric_assortativity_coefficient",
+]
 
 
-def degree_assortativity_coefficient(G, x='out', y='in', weight=None,
-                                     nodes=None):
+def degree_assortativity_coefficient(G, x="out", y="in", weight=None, nodes=None):
     """Compute degree assortativity of graph.
 
     Assortativity measures the similarity of connections
@@ -47,9 +47,9 @@ def degree_assortativity_coefficient(G, x='out', y='in', weight=None,
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> r=nx.degree_assortativity_coefficient(G)
-    >>> print("%3.1f"%r)
+    >>> G = nx.path_graph(4)
+    >>> r = nx.degree_assortativity_coefficient(G)
+    >>> print(f"{r:3.1f}")
     -0.5
 
     See Also
@@ -78,8 +78,7 @@ def degree_assortativity_coefficient(G, x='out', y='in', weight=None,
     return numeric_ac(M)
 
 
-def degree_pearson_correlation_coefficient(G, x='out', y='in',
-                                           weight=None, nodes=None):
+def degree_pearson_correlation_coefficient(G, x="out", y="in", weight=None, nodes=None):
     """Compute degree assortativity of graph.
 
     Assortativity measures the similarity of connections
@@ -114,9 +113,9 @@ def degree_pearson_correlation_coefficient(G, x='out', y='in',
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> r=nx.degree_pearson_correlation_coefficient(G)
-    >>> print("%3.1f"%r)
+    >>> G = nx.path_graph(4)
+    >>> r = nx.degree_pearson_correlation_coefficient(G)
+    >>> print(f"{r:3.1f}")
     -0.5
 
     Notes
@@ -132,9 +131,8 @@ def degree_pearson_correlation_coefficient(G, x='out', y='in',
     """
     try:
         import scipy.stats as stats
-    except ImportError:
-        raise ImportError(
-            "Assortativity requires SciPy: http://scipy.org/ ")
+    except ImportError as e:
+        raise ImportError("Assortativity requires SciPy:" "http://scipy.org/ ") from e
     xy = node_degree_xy(G, x=x, y=y, nodes=nodes, weight=weight)
     x, y = zip(*xy)
     return stats.pearsonr(x, y)[0]
@@ -164,11 +162,11 @@ def attribute_assortativity_coefficient(G, attribute, nodes=None):
 
     Examples
     --------
-    >>> G=nx.Graph()
-    >>> G.add_nodes_from([0,1],color='red')
-    >>> G.add_nodes_from([2,3],color='blue')
-    >>> G.add_edges_from([(0,1),(2,3)])
-    >>> print(nx.attribute_assortativity_coefficient(G,'color'))
+    >>> G = nx.Graph()
+    >>> G.add_nodes_from([0, 1], color="red")
+    >>> G.add_nodes_from([2, 3], color="blue")
+    >>> G.add_edges_from([(0, 1), (2, 3)])
+    >>> print(nx.attribute_assortativity_coefficient(G, "color"))
     1.0
 
     Notes
@@ -212,11 +210,11 @@ def numeric_assortativity_coefficient(G, attribute, nodes=None):
 
     Examples
     --------
-    >>> G=nx.Graph()
-    >>> G.add_nodes_from([0,1],size=2)
-    >>> G.add_nodes_from([2,3],size=3)
-    >>> G.add_edges_from([(0,1),(2,3)])
-    >>> print(nx.numeric_assortativity_coefficient(G,'size'))
+    >>> G = nx.Graph()
+    >>> G.add_nodes_from([0, 1], size=2)
+    >>> G.add_nodes_from([2, 3], size=3)
+    >>> G.add_edges_from([(0, 1), (2, 3)])
+    >>> print(nx.numeric_assortativity_coefficient(G, "size"))
     1.0
 
     Notes
@@ -238,8 +236,8 @@ def attribute_ac(M):
 
     Parameters
     ----------
-    M : numpy array or matrix
-        Attribute mixing matrix.
+    M : numpy.ndarray
+        2D ndarray representing the attribute mixing matrix.
 
     Notes
     -----
@@ -254,16 +252,16 @@ def attribute_ac(M):
     """
     try:
         import numpy
-    except ImportError:
+    except ImportError as e:
         raise ImportError(
-            "attribute_assortativity requires NumPy: http://scipy.org/ ")
+            "attribute_assortativity requires " "NumPy: http://scipy.org/"
+        ) from e
     if M.sum() != 1.0:
-        M = M / float(M.sum())
-    M = numpy.asmatrix(M)
-    s = (M * M).sum()
+        M = M / M.sum()
+    s = (M @ M).sum()
     t = M.trace()
     r = (t - s) / (1 - s)
-    return float(r)
+    return r
 
 
 def numeric_ac(M):
@@ -271,9 +269,10 @@ def numeric_ac(M):
     # numeric assortativity coefficient, pearsonr
     try:
         import numpy
-    except ImportError:
-        raise ImportError('numeric_assortativity requires ',
-                          'NumPy: http://scipy.org/')
+    except ImportError as e:
+        raise ImportError(
+            "numeric_assortativity requires " "NumPy: http://scipy.org/"
+        ) from e
     if M.sum() != 1.0:
         M = M / float(M.sum())
     nx, ny = M.shape  # nx=ny
@@ -281,15 +280,8 @@ def numeric_ac(M):
     y = numpy.arange(ny)
     a = M.sum(axis=0)
     b = M.sum(axis=1)
-    vara = (a * x**2).sum() - ((a * x).sum())**2
-    varb = (b * x**2).sum() - ((b * x).sum())**2
+    vara = (a * x ** 2).sum() - ((a * x).sum()) ** 2
+    varb = (b * x ** 2).sum() - ((b * x).sum()) ** 2
     xy = numpy.outer(x, y)
     ab = numpy.outer(a, b)
     return (xy * (M - ab)).sum() / numpy.sqrt(vara * varb)
-
-
-# fixture for pytest
-def setup_module(module):
-    import pytest
-    numpy = pytest.importorskip('numpy')
-    scipy = pytest.importorskip('scipy')
