@@ -1,24 +1,15 @@
-# Copyright 2016 NetworkX developers.
-# Copyright (C) 2004-2019 by
-#   Aric Hagberg <hagberg@lanl.gov>
-#   Dan Schult <dschult@colgate.edu>
-#   Pieter Swart <swart@lanl.gov>
-#
-# Copyright (C) 2008 by
-#   Joris van Rantwijk.
-#
-# Copyright (C) 2011 by
-#   Nicholas Mancuso <nick.mancuso@gmail.com>
-#
-# All rights reserved.
-# BSD license.
 """Functions for computing and verifying matchings in a graph."""
 from collections import Counter
 from itertools import combinations
 from itertools import repeat
 
-__all__ = ['is_matching', 'is_maximal_matching', 'is_perfect_matching',
-           'max_weight_matching', 'maximal_matching']
+__all__ = [
+    "is_matching",
+    "is_maximal_matching",
+    "is_perfect_matching",
+    "max_weight_matching",
+    "maximal_matching",
+]
 
 
 def maximal_matching(G):
@@ -71,7 +62,7 @@ def matching_dict_to_set(matching):
     # only the (frozen)set `{u, v}` appears as an element in the
     # returned set.
 
-    return set((u, v) for (u, v) in set(map(frozenset, matching.items())))
+    return {(u, v) for (u, v) in set(map(frozenset, matching.items()))}
 
 
 def is_matching(G, matching):
@@ -102,8 +93,7 @@ def is_matching(G, matching):
     if isinstance(matching, dict):
         matching = matching_dict_to_set(matching)
     # TODO This is parallelizable.
-    return all(len(set(e1) & set(e2)) == 0
-               for e1, e2 in combinations(matching, 2))
+    return all(len(set(e1) & set(e2)) == 0 for e1, e2 in combinations(matching, 2))
 
 
 def is_maximal_matching(G, matching):
@@ -186,7 +176,7 @@ def is_perfect_matching(G, matching):
     return all(counts[v] == 1 for v in G)
 
 
-def max_weight_matching(G, maxcardinality=False, weight='weight'):
+def max_weight_matching(G, maxcardinality=False, weight="weight"):
     """Compute a maximum-weighted matching of G.
 
     A matching is a subset of edges in which no node occurs more than once.
@@ -253,12 +243,13 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
 
     class NoNode:
         """Dummy value which is different from any node."""
+
         pass
 
     class Blossom:
         """Representation of a non-trivial blossom or sub-blossom."""
 
-        __slots__ = ['childs', 'edges', 'mybestedges']
+        __slots__ = ["childs", "edges", "mybestedges"]
 
         # b.childs is an ordered list of b's sub-blossoms, starting with
         # the base and going round the blossom.
@@ -276,8 +267,7 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
         def leaves(self):
             for t in self.childs:
                 if isinstance(t, Blossom):
-                    for v in t.leaves():
-                        yield v
+                    yield from t.leaves()
                 else:
                     yield t
 
@@ -293,8 +283,7 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
         wt = d.get(weight, 1)
         if i != j and wt > maxweight:
             maxweight = wt
-        allinteger = allinteger and (str(type(wt)).split("'")[1]
-                                     in ('int', 'long'))
+        allinteger = allinteger and (str(type(wt)).split("'")[1] in ("int", "long"))
 
     # If v is a matched vertex, mate[v] is its partner vertex.
     # If v is a single vertex, v does not occur as a key in mate.
@@ -451,8 +440,9 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
             blossomparent[bv] = b
             path.append(bv)
             edgs.append(labeledge[bv])
-            assert label[bv] == 2 or (label[bv] == 1 and labeledge[
-                                      bv][0] == mate[blossombase[bv]])
+            assert label[bv] == 2 or (
+                label[bv] == 1 and labeledge[bv][0] == mate[blossombase[bv]]
+            )
             # Trace one step back.
             v = labeledge[bv][0]
             bv = inblossom[v]
@@ -466,8 +456,9 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
             blossomparent[bw] = b
             path.append(bw)
             edgs.append((labeledge[bw][1], labeledge[bw][0]))
-            assert label[bw] == 2 or (label[bw] == 1 and labeledge[
-                                      bw][0] == mate[blossombase[bw]])
+            assert label[bw] == 2 or (
+                label[bw] == 1 and labeledge[bw][0] == mate[blossombase[bw]]
+            )
             # Trace one step back.
             w = labeledge[bw][0]
             bw = inblossom[w]
@@ -496,22 +487,21 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
                 else:
                     # This subblossom does not have a list of least-slack
                     # edges; get the information from the vertices.
-                    nblist = [(v, w)
-                              for v in bv.leaves()
-                              for w in G.neighbors(v)
-                              if v != w]
+                    nblist = [
+                        (v, w) for v in bv.leaves() for w in G.neighbors(v) if v != w
+                    ]
             else:
-                nblist = [(bv, w)
-                          for w in G.neighbors(bv)
-                          if bv != w]
+                nblist = [(bv, w) for w in G.neighbors(bv) if bv != w]
             for k in nblist:
                 (i, j) = k
                 if inblossom[j] == b:
                     i, j = j, i
                 bj = inblossom[j]
-                if (bj != b and label.get(bj) == 1 and
-                    ((bj not in bestedgeto) or
-                     slack(i, j) < slack(*bestedgeto[bj]))):
+                if (
+                    bj != b
+                    and label.get(bj) == 1
+                    and ((bj not in bestedgeto) or slack(i, j) < slack(*bestedgeto[bj]))
+                ):
                     bestedgeto[bj] = k
             # Forget about least-slack edge of the subblossom.
             bestedge[bv] = None
@@ -676,9 +666,9 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
             while 1:
                 bs = inblossom[s]
                 assert label[bs] == 1
-                assert (
-                    labeledge[bs] is None and blossombase[bs] not in mate)\
-                    or (labeledge[bs][0] == mate[blossombase[bs]])
+                assert (labeledge[bs] is None and blossombase[bs] not in mate) or (
+                    labeledge[bs][0] == mate[blossombase[bs]]
+                )
                 # Augment through the S-blossom from s to base.
                 if isinstance(bs, Blossom):
                     augmentBlossom(bs, s)
@@ -838,15 +828,13 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
                     elif label.get(bw) == 1:
                         # keep track of the least-slack non-allowable edge to
                         # a different S-blossom.
-                        if bestedge.get(bv) is None or \
-                                kslack < slack(*bestedge[bv]):
+                        if bestedge.get(bv) is None or kslack < slack(*bestedge[bv]):
                             bestedge[bv] = (v, w)
                     elif label.get(w) is None:
                         # w is a free vertex (or an unreached vertex inside
                         # a T-blossom) but we can not reach it yet;
                         # keep track of the least-slack edge that reaches w.
-                        if bestedge.get(w) is None or \
-                                kslack < slack(*bestedge[w]):
+                        if bestedge.get(w) is None or kslack < slack(*bestedge[w]):
                             bestedge[w] = (v, w)
 
             if augmented:
@@ -867,8 +855,7 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
             # Compute delta2: the minimum slack on any edge between
             # an S-vertex and a free vertex.
             for v in G.nodes():
-                if label.get(inblossom[v]) is None and \
-                        bestedge.get(v) is not None:
+                if label.get(inblossom[v]) is None and bestedge.get(v) is not None:
                     d = slack(*bestedge[v])
                     if deltatype == -1 or d < delta:
                         delta = d
@@ -878,8 +865,11 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
             # Compute delta3: half the minimum slack on any edge between
             # a pair of S-blossoms.
             for b in blossomparent:
-                if (blossomparent[b] is None and label.get(b) == 1 and
-                        bestedge.get(b) is not None):
+                if (
+                    blossomparent[b] is None
+                    and label.get(b) == 1
+                    and bestedge.get(b) is not None
+                ):
                     kslack = slack(*bestedge[b])
                     if allinteger:
                         assert (kslack % 2) == 0
@@ -893,8 +883,11 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
 
             # Compute delta4: minimum z variable of any T-blossom.
             for b in blossomdual:
-                if (blossomparent[b] is None and label.get(b) == 2 and
-                        (deltatype == -1 or blossomdual[b] < delta)):
+                if (
+                    blossomparent[b] is None
+                    and label.get(b) == 2
+                    and (deltatype == -1 or blossomdual[b] < delta)
+                ):
                     delta = blossomdual[b]
                     deltatype = 4
                     deltablossom = b
@@ -958,8 +951,7 @@ def max_weight_matching(G, maxcardinality=False, weight='weight'):
         for b in list(blossomdual.keys()):
             if b not in blossomdual:
                 continue  # already expanded
-            if (blossomparent[b] is None and label.get(b) == 1 and
-                    blossomdual[b] == 0):
+            if blossomparent[b] is None and label.get(b) == 1 and blossomdual[b] == 0:
                 expandBlossom(b, True)
 
     # Verify that we reached the optimum solution (only for integer weights).
