@@ -1,20 +1,11 @@
 """Unary operations on graphs"""
-#    Copyright (C) 2004-2018 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
 import networkx as nx
-from networkx.utils import not_implemented_for
-__author__ = """\n""".join(['Aric Hagberg <aric.hagberg@gmail.com>',
-                            'Pieter Swart (swart@lanl.gov)',
-                            'Dan Schult(dschult@colgate.edu)'])
-__all__ = ['complement', 'reverse']
+
+__all__ = ["complement", "reverse"]
 
 
 def complement(G):
-    """Return the graph complement of G.
+    """Returns the graph complement of G.
 
     Parameters
     ----------
@@ -32,17 +23,16 @@ def complement(G):
 
     Graph, node, and edge data are not propagated to the new graph.
     """
-    R = G.fresh_copy()
+    R = G.__class__()
     R.add_nodes_from(G)
-    R.add_edges_from(((n, n2)
-                      for n, nbrs in G.adjacency()
-                      for n2 in G if n2 not in nbrs
-                      if n != n2))
+    R.add_edges_from(
+        ((n, n2) for n, nbrs in G.adjacency() for n2 in G if n2 not in nbrs if n != n2)
+    )
     return R
 
 
 def reverse(G, copy=True):
-    """Return the reverse directed graph of G.
+    """Returns the reverse directed graph of G.
 
     Parameters
     ----------
