@@ -1,15 +1,6 @@
-# test_chains.py - unit tests for the chains module
-#
-# Copyright 2004-2019 NetworkX developers.
-#
-# This file is part of NetworkX.
-#
-# NetworkX is distributed under a BSD license; see LICENSE.txt for more
-# information.
 """Unit tests for the chain decomposition functions."""
 from itertools import cycle
 from itertools import islice
-from unittest import TestCase
 
 import networkx as nx
 
@@ -19,7 +10,7 @@ def cycles(seq):
 
     For example::
 
-        >>> list(cycles('abc'))
+        >>> list(cycles("abc"))
         [('a', 'b', 'c'), ('b', 'c', 'a'), ('c', 'a', 'b')]
 
     """
@@ -35,9 +26,9 @@ def cyclic_equals(seq1, seq2):
 
     For example::
 
-        >>> cyclic_equals('xyz', 'zxy')
+        >>> cyclic_equals("xyz", "zxy")
         True
-        >>> cyclic_equals('xyz', 'zyx')
+        >>> cyclic_equals("xyz", "zyx")
         False
 
     """
@@ -46,7 +37,7 @@ def cyclic_equals(seq1, seq2):
     return any(x == tuple(seq2) for x in cycles(seq1))
 
 
-class TestChainDecomposition(TestCase):
+class TestChainDecomposition:
     """Unit tests for the chain decomposition function."""
 
     def assertContainsChain(self, chain, expected):
@@ -60,15 +51,26 @@ class TestChainDecomposition(TestCase):
             if cyclic_equals(reversed_chain, candidate):
                 break
         else:
-            self.fail('chain not found')
+            self.fail("chain not found")
 
     def test_decomposition(self):
         edges = [
             # DFS tree edges.
-            (1, 2), (2, 3), (3, 4), (3, 5), (5, 6), (6, 7), (7, 8), (5, 9),
+            (1, 2),
+            (2, 3),
+            (3, 4),
+            (3, 5),
+            (5, 6),
+            (6, 7),
+            (7, 8),
+            (5, 9),
             (9, 10),
             # Nontree edges.
-            (1, 3), (1, 4), (2, 5), (5, 10), (6, 8)
+            (1, 3),
+            (1, 4),
+            (2, 5),
+            (5, 10),
+            (6, 8),
         ]
         G = nx.Graph(edges)
         expected = [
@@ -79,21 +81,19 @@ class TestChainDecomposition(TestCase):
             [(6, 8), (8, 7), (7, 6)],
         ]
         chains = list(nx.chain_decomposition(G, root=1))
-        self.assertEqual(len(chains), len(expected))
-# This chain decomposition isn't unique
-#        for chain in chains:
-#            print(chain)
-#            self.assertContainsChain(chain, expected)
+        assert len(chains) == len(expected)
+
+    # This chain decomposition isn't unique
+    #        for chain in chains:
+    #            print(chain)
+    #            self.assertContainsChain(chain, expected)
 
     def test_barbell_graph(self):
         # The (3, 0) barbell graph has two triangles joined by a single edge.
         G = nx.barbell_graph(3, 0)
         chains = list(nx.chain_decomposition(G, root=0))
-        expected = [
-            [(0, 1), (1, 2), (2, 0)],
-            [(3, 4), (4, 5), (5, 3)],
-        ]
-        self.assertEqual(len(chains), len(expected))
+        expected = [[(0, 1), (1, 2), (2, 0)], [(3, 4), (4, 5), (5, 3)]]
+        assert len(chains) == len(expected)
         for chain in chains:
             self.assertContainsChain(chain, expected)
 
@@ -101,17 +101,17 @@ class TestChainDecomposition(TestCase):
         """Test for a graph with multiple connected components."""
         G = nx.barbell_graph(3, 0)
         H = nx.barbell_graph(3, 0)
-        mapping = dict(zip(range(6), 'abcdef'))
+        mapping = dict(zip(range(6), "abcdef"))
         nx.relabel_nodes(H, mapping, copy=False)
         G = nx.union(G, H)
         chains = list(nx.chain_decomposition(G))
         expected = [
             [(0, 1), (1, 2), (2, 0)],
             [(3, 4), (4, 5), (5, 3)],
-            [('a', 'b'), ('b', 'c'), ('c', 'a')],
-            [('d', 'e'), ('e', 'f'), ('f', 'd')],
+            [("a", "b"), ("b", "c"), ("c", "a")],
+            [("d", "e"), ("e", "f"), ("f", "d")],
         ]
-        self.assertEqual(len(chains), len(expected))
+        assert len(chains) == len(expected)
         for chain in chains:
             self.assertContainsChain(chain, expected)
 
@@ -119,14 +119,14 @@ class TestChainDecomposition(TestCase):
         """Test for a single component of a disconnected graph."""
         G = nx.barbell_graph(3, 0)
         H = nx.barbell_graph(3, 0)
-        mapping = dict(zip(range(6), 'abcdef'))
+        mapping = dict(zip(range(6), "abcdef"))
         nx.relabel_nodes(H, mapping, copy=False)
         G = nx.union(G, H)
-        chains = list(nx.chain_decomposition(G, root='a'))
+        chains = list(nx.chain_decomposition(G, root="a"))
         expected = [
-            [('a', 'b'), ('b', 'c'), ('c', 'a')],
-            [('d', 'e'), ('e', 'f'), ('f', 'd')],
+            [("a", "b"), ("b", "c"), ("c", "a")],
+            [("d", "e"), ("e", "f"), ("f", "d")],
         ]
-        self.assertEqual(len(chains), len(expected))
+        assert len(chains) == len(expected)
         for chain in chains:
             self.assertContainsChain(chain, expected)
