@@ -1,11 +1,3 @@
-#    Copyright (C) 2004-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Author: Aric Hagberg (hagberg@lanl.gov)
 """
 **********
 Matplotlib
@@ -23,24 +15,31 @@ pygraphviz:     http://pygraphviz.github.io/
 """
 from numbers import Number
 import networkx as nx
-from networkx.utils import is_string_like
-from networkx.drawing.layout import shell_layout, \
-    circular_layout, kamada_kawai_layout, spectral_layout, \
-    spring_layout, random_layout, planar_layout
+from networkx.drawing.layout import (
+    shell_layout,
+    circular_layout,
+    kamada_kawai_layout,
+    spectral_layout,
+    spring_layout,
+    random_layout,
+    planar_layout,
+)
 
-__all__ = ['draw',
-           'draw_networkx',
-           'draw_networkx_nodes',
-           'draw_networkx_edges',
-           'draw_networkx_labels',
-           'draw_networkx_edge_labels',
-           'draw_circular',
-           'draw_kamada_kawai',
-           'draw_random',
-           'draw_spectral',
-           'draw_spring',
-           'draw_planar',
-           'draw_shell']
+__all__ = [
+    "draw",
+    "draw_networkx",
+    "draw_networkx_nodes",
+    "draw_networkx_edges",
+    "draw_networkx_labels",
+    "draw_networkx_edge_labels",
+    "draw_circular",
+    "draw_kamada_kawai",
+    "draw_random",
+    "draw_spectral",
+    "draw_spring",
+    "draw_planar",
+    "draw_shell",
+]
 
 
 def draw(G, pos=None, ax=None, **kwds):
@@ -92,7 +91,6 @@ def draw(G, pos=None, ax=None, **kwds):
     With pyplot use
 
     >>> import matplotlib.pyplot as plt
-    >>> import networkx as nx
     >>> G = nx.dodecahedral_graph()
     >>> nx.draw(G)  # networkx draw()
     >>> plt.draw()  # pyplot draw()
@@ -102,8 +100,8 @@ def draw(G, pos=None, ax=None, **kwds):
     """
     try:
         import matplotlib.pyplot as plt
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
@@ -112,15 +110,15 @@ def draw(G, pos=None, ax=None, **kwds):
         cf = plt.gcf()
     else:
         cf = ax.get_figure()
-    cf.set_facecolor('w')
+    cf.set_facecolor("w")
     if ax is None:
         if cf._axstack() is None:
             ax = cf.add_axes((0, 0, 1, 1))
         else:
             ax = cf.gca()
 
-    if 'with_labels' not in kwds:
-        kwds['with_labels'] = 'labels' in kwds
+    if "with_labels" not in kwds:
+        kwds["with_labels"] = "labels" in kwds
 
     draw_networkx(G, pos=pos, ax=ax, **kwds)
     ax.set_axis_off()
@@ -233,7 +231,11 @@ def draw_networkx(G, pos=None, arrows=True, with_labels=True, **kwds):
        Font family
 
     label : string, optional
-        Label for graph legend
+       Label for graph legend
+
+    kwds : optional keywords
+       See networkx.draw_networkx_nodes(), networkx.draw_networkx_edges(), and
+       networkx.draw_networkx_labels() for a description of optional keywords.
 
     Notes
     -----
@@ -247,7 +249,7 @@ def draw_networkx(G, pos=None, arrows=True, with_labels=True, **kwds):
     >>> nx.draw(G, pos=nx.spring_layout(G))  # use spring layout
 
     >>> import matplotlib.pyplot as plt
-    >>> limits = plt.axis('off')  # turn of axis
+    >>> limits = plt.axis("off")  # turn of axis
 
     Also see the NetworkX drawing examples at
     https://networkx.github.io/documentation/latest/auto_examples/index.html
@@ -262,36 +264,97 @@ def draw_networkx(G, pos=None, arrows=True, with_labels=True, **kwds):
     """
     try:
         import matplotlib.pyplot as plt
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
 
+    valid_node_kwds = (
+        "nodelist",
+        "node_size",
+        "node_color",
+        "node_shape",
+        "alpha",
+        "cmap",
+        "vmin",
+        "vmax",
+        "ax",
+        "linewidths",
+        "edgecolors",
+        "label",
+    )
+
+    valid_edge_kwds = (
+        "edgelist",
+        "width",
+        "edge_color",
+        "style",
+        "alpha",
+        "arrowstyle",
+        "arrowsize",
+        "edge_cmap",
+        "edge_vmin",
+        "edge_vmax",
+        "ax",
+        "label",
+        "node_size",
+        "nodelist",
+        "node_shape",
+        "connectionstyle",
+        "min_source_margin",
+        "min_target_margin",
+    )
+
+    valid_label_kwds = (
+        "labels",
+        "font_size",
+        "font_color",
+        "font_family",
+        "font_weight",
+        "alpha",
+        "bbox",
+        "ax",
+        "horizontalalignment",
+        "verticalalignment",
+    )
+
+    valid_kwds = valid_node_kwds + valid_edge_kwds + valid_label_kwds
+
+    if any([k not in valid_kwds for k in kwds]):
+        invalid_args = ", ".join([k for k in kwds if k not in valid_kwds])
+        raise ValueError(f"Received invalid argument(s): {invalid_args}")
+
+    node_kwds = {k: v for k, v in kwds.items() if k in valid_node_kwds}
+    edge_kwds = {k: v for k, v in kwds.items() if k in valid_edge_kwds}
+    label_kwds = {k: v for k, v in kwds.items() if k in valid_label_kwds}
+
     if pos is None:
         pos = nx.drawing.spring_layout(G)  # default to spring layout
 
-    node_collection = draw_networkx_nodes(G, pos, **kwds)
-    edge_collection = draw_networkx_edges(G, pos, arrows=arrows, **kwds)
+    draw_networkx_nodes(G, pos, **node_kwds)
+    draw_networkx_edges(G, pos, arrows=arrows, **edge_kwds)
     if with_labels:
-        draw_networkx_labels(G, pos, **kwds)
+        draw_networkx_labels(G, pos, **label_kwds)
     plt.draw_if_interactive()
 
 
-def draw_networkx_nodes(G, pos,
-                        nodelist=None,
-                        node_size=300,
-                        node_color='#1f78b4',
-                        node_shape='o',
-                        alpha=None,
-                        cmap=None,
-                        vmin=None,
-                        vmax=None,
-                        ax=None,
-                        linewidths=None,
-                        edgecolors=None,
-                        label=None,
-                        **kwds):
+def draw_networkx_nodes(
+    G,
+    pos,
+    nodelist=None,
+    node_size=300,
+    node_color="#1f78b4",
+    node_shape="o",
+    alpha=None,
+    cmap=None,
+    vmin=None,
+    vmax=None,
+    ax=None,
+    linewidths=None,
+    edgecolors=None,
+    label=None,
+):
     """Draw the nodes of the graph G.
 
     This draws only the nodes of the graph G.
@@ -347,12 +410,6 @@ def draw_networkx_nodes(G, pos,
     label : [None| string]
        Label for legend
 
-    min_source_margin : int, optional (default=0)
-       The minimum margin (gap) at the begining of the edge at the source.
-
-    min_target_margin : int, optional (default=0)
-       The minimum margin (gap) at the end of the edge at the target.
-
     Returns
     -------
     matplotlib.collections.PathCollection
@@ -375,11 +432,13 @@ def draw_networkx_nodes(G, pos,
     draw_networkx_edge_labels()
     """
     from collections.abc import Iterable
+
     try:
         import matplotlib.pyplot as plt
+        from matplotlib.collections import PathCollection
         import numpy as np
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
@@ -391,63 +450,69 @@ def draw_networkx_nodes(G, pos,
         nodelist = list(G)
 
     if len(nodelist) == 0:  # empty nodelist, no drawing
-        return
+        return PathCollection(None)
 
     try:
         xy = np.asarray([pos[v] for v in nodelist])
     except KeyError as e:
-        raise nx.NetworkXError('Node %s has no position.' % e)
-    except ValueError:
-        raise nx.NetworkXError('Bad value in node positions.')
+        raise nx.NetworkXError(f"Node {e} has no position.") from e
+    except ValueError as e:
+        raise nx.NetworkXError("Bad value in node positions.") from e
 
     if isinstance(alpha, Iterable):
         node_color = apply_alpha(node_color, alpha, nodelist, cmap, vmin, vmax)
         alpha = None
 
-    node_collection = ax.scatter(xy[:, 0], xy[:, 1],
-                                 s=node_size,
-                                 c=node_color,
-                                 marker=node_shape,
-                                 cmap=cmap,
-                                 vmin=vmin,
-                                 vmax=vmax,
-                                 alpha=alpha,
-                                 linewidths=linewidths,
-                                 edgecolors=edgecolors,
-                                 label=label)
+    node_collection = ax.scatter(
+        xy[:, 0],
+        xy[:, 1],
+        s=node_size,
+        c=node_color,
+        marker=node_shape,
+        cmap=cmap,
+        vmin=vmin,
+        vmax=vmax,
+        alpha=alpha,
+        linewidths=linewidths,
+        edgecolors=edgecolors,
+        label=label,
+    )
     ax.tick_params(
-        axis='both',
-        which='both',
+        axis="both",
+        which="both",
         bottom=False,
         left=False,
         labelbottom=False,
-        labelleft=False)
+        labelleft=False,
+    )
 
     node_collection.set_zorder(2)
     return node_collection
 
 
-def draw_networkx_edges(G, pos,
-                        edgelist=None,
-                        width=1.0,
-                        edge_color='k',
-                        style='solid',
-                        alpha=None,
-                        arrowstyle='-|>',
-                        arrowsize=10,
-                        edge_cmap=None,
-                        edge_vmin=None,
-                        edge_vmax=None,
-                        ax=None,
-                        arrows=True,
-                        label=None,
-                        node_size=300,
-                        nodelist=None,
-                        node_shape="o",
-                        connectionstyle=None,
-                        min_source_margin=0,
-                        min_target_margin=0,
-                        **kwds):
+def draw_networkx_edges(
+    G,
+    pos,
+    edgelist=None,
+    width=1.0,
+    edge_color="k",
+    style="solid",
+    alpha=None,
+    arrowstyle="-|>",
+    arrowsize=10,
+    edge_cmap=None,
+    edge_vmin=None,
+    edge_vmax=None,
+    ax=None,
+    arrows=True,
+    label=None,
+    node_size=300,
+    nodelist=None,
+    node_shape="o",
+    connectionstyle=None,
+    min_source_margin=0,
+    min_target_margin=0,
+):
     """Draw the edges of the graph G.
 
     This draws only the edges of the graph G.
@@ -557,14 +622,13 @@ def draw_networkx_edges(G, pos,
     draw_networkx_edge_labels()
     """
     try:
-        import matplotlib
         import matplotlib.pyplot as plt
         from matplotlib.colors import colorConverter, Colormap, Normalize
         from matplotlib.collections import LineCollection
         from matplotlib.patches import FancyArrowPatch
         import numpy as np
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
@@ -575,25 +639,31 @@ def draw_networkx_edges(G, pos,
     if edgelist is None:
         edgelist = list(G.edges())
 
-    if not edgelist or len(edgelist) == 0:  # no edges!
-        return None
+    if len(edgelist) == 0:  # no edges!
+        if not G.is_directed() or not arrows:
+            return LineCollection(None)
+        else:
+            return []
 
     if nodelist is None:
         nodelist = list(G.nodes())
 
     # FancyArrowPatch handles color=None different from LineCollection
     if edge_color is None:
-        edge_color = 'k'
+        edge_color = "k"
 
     # set edge positions
     edge_pos = np.asarray([(pos[e[0]], pos[e[1]]) for e in edgelist])
 
     # Check if edge_color is an array of floats and map to edge_cmap.
     # This is the only case handled differently from matplotlib
-    if np.iterable(edge_color) and (len(edge_color) == len(edge_pos)) \
-            and np.alltrue([isinstance(c, Number) for c in edge_color]):
+    if (
+        np.iterable(edge_color)
+        and (len(edge_color) == len(edge_pos))
+        and np.alltrue([isinstance(c, Number) for c in edge_color])
+    ):
         if edge_cmap is not None:
-            assert(isinstance(edge_cmap, Colormap))
+            assert isinstance(edge_cmap, Colormap)
         else:
             edge_cmap = plt.get_cmap()
         if edge_vmin is None:
@@ -603,15 +673,19 @@ def draw_networkx_edges(G, pos,
         color_normal = Normalize(vmin=edge_vmin, vmax=edge_vmax)
         edge_color = [edge_cmap(color_normal(e)) for e in edge_color]
 
-    if (not G.is_directed() or not arrows):
-        edge_collection = LineCollection(edge_pos,
-                                         colors=edge_color,
-                                         linewidths=width,
-                                         antialiaseds=(1,),
-                                         linestyle=style,
-                                         transOffset=ax.transData,
-                                         alpha=alpha
-                                         )
+    if not G.is_directed() or not arrows:
+        edge_collection = LineCollection(
+            edge_pos,
+            colors=edge_color,
+            linewidths=width,
+            antialiaseds=(1,),
+            linestyle=style,
+            transOffset=ax.transData,
+            alpha=alpha,
+        )
+
+        edge_collection.set_cmap(edge_cmap)
+        edge_collection.set_clim(edge_vmin, edge_vmax)
 
         edge_collection.set_zorder(1)  # edges go behind nodes
         edge_collection.set_label(label)
@@ -644,12 +718,13 @@ def draw_networkx_edges(G, pos,
             shrink_source = 0  # space from source to tail
             shrink_target = 0  # space from  head to target
             if np.iterable(node_size):  # many node sizes
-                src_node, dst_node = edgelist[i][:2]
-                index_node = nodelist.index(dst_node)
-                marker_size = node_size[index_node]
-                shrink_target = to_marker_edge(marker_size, node_shape)
+                source, target = edgelist[i][:2]
+                source_node_size = node_size[nodelist.index(source)]
+                target_node_size = node_size[nodelist.index(target)]
+                shrink_source = to_marker_edge(source_node_size, node_shape)
+                shrink_target = to_marker_edge(target_node_size, node_shape)
             else:
-                shrink_target = to_marker_edge(node_size, node_shape)
+                shrink_source = shrink_target = to_marker_edge(node_size, node_shape)
 
             if shrink_source < min_source_margin:
                 shrink_source = min_source_margin
@@ -672,15 +747,19 @@ def draw_networkx_edges(G, pos,
             else:
                 line_width = width
 
-            arrow = FancyArrowPatch((x1, y1), (x2, y2),
-                                    arrowstyle=arrowstyle,
-                                    shrinkA=shrink_source,
-                                    shrinkB=shrink_target,
-                                    mutation_scale=mutation_scale,
-                                    color=arrow_color,
-                                    linewidth=line_width,
-                                    connectionstyle=connectionstyle,
-                                    zorder=1)  # arrows go behind nodes
+            arrow = FancyArrowPatch(
+                (x1, y1),
+                (x2, y2),
+                arrowstyle=arrowstyle,
+                shrinkA=shrink_source,
+                shrinkB=shrink_target,
+                mutation_scale=mutation_scale,
+                color=arrow_color,
+                linewidth=line_width,
+                connectionstyle=connectionstyle,
+                linestyle=style,
+                zorder=1,
+            )  # arrows go behind nodes
 
             # There seems to be a bug in matplotlib to make collections of
             # FancyArrowPatch instances. Until fixed, the patches are added
@@ -696,32 +775,37 @@ def draw_networkx_edges(G, pos,
 
     w = maxx - minx
     h = maxy - miny
-    padx,  pady = 0.05 * w, 0.05 * h
+    padx, pady = 0.05 * w, 0.05 * h
     corners = (minx - padx, miny - pady), (maxx + padx, maxy + pady)
     ax.update_datalim(corners)
     ax.autoscale_view()
 
     ax.tick_params(
-        axis='both',
-        which='both',
+        axis="both",
+        which="both",
         bottom=False,
         left=False,
         labelbottom=False,
-        labelleft=False)
+        labelleft=False,
+    )
 
     return arrow_collection
 
 
-def draw_networkx_labels(G, pos,
-                         labels=None,
-                         font_size=12,
-                         font_color='k',
-                         font_family='sans-serif',
-                         font_weight='normal',
-                         alpha=None,
-                         bbox=None,
-                         ax=None,
-                         **kwds):
+def draw_networkx_labels(
+    G,
+    pos,
+    labels=None,
+    font_size=12,
+    font_color="k",
+    font_family="sans-serif",
+    font_weight="normal",
+    alpha=None,
+    bbox=None,
+    horizontalalignment="center",
+    verticalalignment="center",
+    ax=None,
+):
     """Draw node labels on the graph G.
 
     Parameters
@@ -753,9 +837,16 @@ def draw_networkx_labels(G, pos,
     alpha : float or None
        The text transparency (default=None)
 
+    horizontalalignment : {'center', 'right', 'left'}
+       Horizontal alignment (default='center')
+
+    verticalalignment : {'center', 'top', 'bottom', 'baseline', 'center_baseline'}
+        Vertical alignment (default='center')
+
     ax : Matplotlib Axes object, optional
        Draw the graph in the specified Matplotlib axes.
 
+
     Returns
     -------
     dict
@@ -779,8 +870,8 @@ def draw_networkx_labels(G, pos,
     """
     try:
         import matplotlib.pyplot as plt
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
@@ -789,55 +880,58 @@ def draw_networkx_labels(G, pos,
         ax = plt.gca()
 
     if labels is None:
-        labels = dict((n, n) for n in G.nodes())
-
-    # set optional alignment
-    horizontalalignment = kwds.get('horizontalalignment', 'center')
-    verticalalignment = kwds.get('verticalalignment', 'center')
+        labels = {n: n for n in G.nodes()}
 
     text_items = {}  # there is no text collection so we'll fake one
     for n, label in labels.items():
         (x, y) = pos[n]
-        if not is_string_like(label):
+        if not isinstance(label, str):
             label = str(label)  # this makes "1" and 1 labeled the same
-        t = ax.text(x, y,
-                    label,
-                    size=font_size,
-                    color=font_color,
-                    family=font_family,
-                    weight=font_weight,
-                    alpha=alpha,
-                    horizontalalignment=horizontalalignment,
-                    verticalalignment=verticalalignment,
-                    transform=ax.transData,
-                    bbox=bbox,
-                    clip_on=True,
-                    )
+        t = ax.text(
+            x,
+            y,
+            label,
+            size=font_size,
+            color=font_color,
+            family=font_family,
+            weight=font_weight,
+            alpha=alpha,
+            horizontalalignment=horizontalalignment,
+            verticalalignment=verticalalignment,
+            transform=ax.transData,
+            bbox=bbox,
+            clip_on=True,
+        )
         text_items[n] = t
 
     ax.tick_params(
-        axis='both',
-        which='both',
+        axis="both",
+        which="both",
         bottom=False,
         left=False,
         labelbottom=False,
-        labelleft=False)
+        labelleft=False,
+    )
 
     return text_items
 
 
-def draw_networkx_edge_labels(G, pos,
-                              edge_labels=None,
-                              label_pos=0.5,
-                              font_size=10,
-                              font_color='k',
-                              font_family='sans-serif',
-                              font_weight='normal',
-                              alpha=None,
-                              bbox=None,
-                              ax=None,
-                              rotate=True,
-                              **kwds):
+def draw_networkx_edge_labels(
+    G,
+    pos,
+    edge_labels=None,
+    label_pos=0.5,
+    font_size=10,
+    font_color="k",
+    font_family="sans-serif",
+    font_weight="normal",
+    alpha=None,
+    bbox=None,
+    horizontalalignment="center",
+    verticalalignment="center",
+    ax=None,
+    rotate=True,
+):
     """Draw edge labels.
 
     Parameters
@@ -881,6 +975,15 @@ def draw_networkx_edge_labels(G, pos,
     clip_on : bool
        Turn on clipping at axis boundaries (default=True)
 
+    horizontalalignment : {'center', 'right', 'left'}
+       Horizontal alignment (default='center')
+
+    verticalalignment : {'center', 'top', 'bottom', 'baseline', 'center_baseline'}
+        Vertical alignment (default='center')
+
+    ax : Matplotlib Axes object, optional
+       Draw the graph in the specified Matplotlib axes.
+
     Returns
     -------
     dict
@@ -905,8 +1008,8 @@ def draw_networkx_edge_labels(G, pos,
     try:
         import matplotlib.pyplot as plt
         import numpy as np
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
     except RuntimeError:
         print("Matplotlib unable to open display")
         raise
@@ -921,8 +1024,10 @@ def draw_networkx_edge_labels(G, pos,
     for (n1, n2), label in labels.items():
         (x1, y1) = pos[n1]
         (x2, y2) = pos[n2]
-        (x, y) = (x1 * label_pos + x2 * (1.0 - label_pos),
-                  y1 * label_pos + y2 * (1.0 - label_pos))
+        (x, y) = (
+            x1 * label_pos + x2 * (1.0 - label_pos),
+            y1 * label_pos + y2 * (1.0 - label_pos),
+        )
 
         if rotate:
             # in degrees
@@ -930,51 +1035,48 @@ def draw_networkx_edge_labels(G, pos,
             # make label orientation "right-side-up"
             if angle > 90:
                 angle -= 180
-            if angle < - 90:
+            if angle < -90:
                 angle += 180
             # transform data coordinate angle to screen coordinate angle
             xy = np.array((x, y))
-            trans_angle = ax.transData.transform_angles(np.array((angle,)),
-                                                        xy.reshape((1, 2)))[0]
+            trans_angle = ax.transData.transform_angles(
+                np.array((angle,)), xy.reshape((1, 2))
+            )[0]
         else:
             trans_angle = 0.0
         # use default box of white with white border
         if bbox is None:
-            bbox = dict(boxstyle='round',
-                        ec=(1.0, 1.0, 1.0),
-                        fc=(1.0, 1.0, 1.0),
-                        )
-        if not is_string_like(label):
+            bbox = dict(boxstyle="round", ec=(1.0, 1.0, 1.0), fc=(1.0, 1.0, 1.0))
+        if not isinstance(label, str):
             label = str(label)  # this makes "1" and 1 labeled the same
 
-        # set optional alignment
-        horizontalalignment = kwds.get('horizontalalignment', 'center')
-        verticalalignment = kwds.get('verticalalignment', 'center')
-
-        t = ax.text(x, y,
-                    label,
-                    size=font_size,
-                    color=font_color,
-                    family=font_family,
-                    weight=font_weight,
-                    alpha=alpha,
-                    horizontalalignment=horizontalalignment,
-                    verticalalignment=verticalalignment,
-                    rotation=trans_angle,
-                    transform=ax.transData,
-                    bbox=bbox,
-                    zorder=1,
-                    clip_on=True,
-                    )
+        t = ax.text(
+            x,
+            y,
+            label,
+            size=font_size,
+            color=font_color,
+            family=font_family,
+            weight=font_weight,
+            alpha=alpha,
+            horizontalalignment=horizontalalignment,
+            verticalalignment=verticalalignment,
+            rotation=trans_angle,
+            transform=ax.transData,
+            bbox=bbox,
+            zorder=1,
+            clip_on=True,
+        )
         text_items[(n1, n2)] = t
 
     ax.tick_params(
-        axis='both',
-        which='both',
+        axis="both",
+        which="both",
         bottom=False,
         left=False,
         labelbottom=False,
-        labelleft=False)
+        labelleft=False,
+    )
 
     return text_items
 
@@ -1030,7 +1132,7 @@ def draw_random(G, **kwargs):
 def draw_spectral(G, **kwargs):
     """Draw the graph G with a spectral 2D layout.
 
-    Using the unnormalized Laplacion, the layout shows possible clusters of
+    Using the unnormalized Laplacian, the layout shows possible clusters of
     nodes which are an approximation of the ratio cut. The positions are the
     entries of the second and third eigenvectors corresponding to the
     ascending eigenvalues starting from the second one.
@@ -1077,9 +1179,9 @@ def draw_shell(G, **kwargs):
        with the exception of the pos parameter which is not used by this
        function.
     """
-    nlist = kwargs.get('nlist', None)
+    nlist = kwargs.get("nlist", None)
     if nlist is not None:
-        del(kwargs['nlist'])
+        del kwargs["nlist"]
     draw(G, shell_layout(G, nlist=nlist), **kwargs)
 
 
@@ -1143,8 +1245,8 @@ def apply_alpha(colors, alpha, elem_list, cmap=None, vmin=None, vmax=None):
         import numpy as np
         from matplotlib.colors import colorConverter
         import matplotlib.cm as cm
-    except ImportError:
-        raise ImportError("Matplotlib required for draw()")
+    except ImportError as e:
+        raise ImportError("Matplotlib required for draw()") from e
 
     # If we have been provided with a list of numbers as long as elem_list,
     # apply the color mapping.
@@ -1159,8 +1261,7 @@ def apply_alpha(colors, alpha, elem_list, cmap=None, vmin=None, vmax=None):
         try:
             rgba_colors = np.array([colorConverter.to_rgba(colors)])
         except ValueError:
-            rgba_colors = np.array([colorConverter.to_rgba(color)
-                                    for color in colors])
+            rgba_colors = np.array([colorConverter.to_rgba(color) for color in colors])
     # Set the final column of the rgba_colors to have the relevant alpha values
     try:
         # If alpha is longer than the number of colors, resize to the number of
@@ -1172,15 +1273,7 @@ def apply_alpha(colors, alpha, elem_list, cmap=None, vmin=None, vmax=None):
             rgba_colors[1:, 0] = rgba_colors[0, 0]
             rgba_colors[1:, 1] = rgba_colors[0, 1]
             rgba_colors[1:, 2] = rgba_colors[0, 2]
-        rgba_colors[:,  3] = list(islice(cycle(alpha), len(rgba_colors)))
+        rgba_colors[:, 3] = list(islice(cycle(alpha), len(rgba_colors)))
     except TypeError:
         rgba_colors[:, -1] = alpha
     return rgba_colors
-
-
-# fixture for pytest
-def setup_module(module):
-    import pytest
-    mpl = pytest.importorskip('matplotlib')
-    mpl.use('PS', warn=False)
-    plt = pytest.importorskip('matplotlib.pyplot')
