@@ -1,24 +1,12 @@
-#    Copyright (C) 2013-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Authors:      James Clough <james.clough91@gmail.com>
-#               Aric Hagberg <hagberg@lanl.gov>
-#               Pieter Swart <swart@lanl.gov>
-#               Dan Schult <dschult@colgate.edu>
-#               chebee7i <chebee7i@gmail.com>
 """Functions for generating line graphs."""
 from itertools import combinations
 from collections import defaultdict
 
 import networkx as nx
 from networkx.utils import arbitrary_element, generate_unique_node
-from networkx.utils.decorators import *
+from networkx.utils.decorators import not_implemented_for
 
-__all__ = ['line_graph', 'inverse_line_graph']
+__all__ = ["line_graph", "inverse_line_graph"]
 
 
 def line_graph(G, create_using=None):
@@ -49,7 +37,6 @@ def line_graph(G, create_using=None):
 
     Examples
     --------
-    >>> import networkx as nx
     >>> G = nx.star_graph(3)
     >>> L = nx.line_graph(G)
     >>> print(sorted(map(sorted, L.edges())))  # makes a 3-clique, K3
@@ -126,11 +113,15 @@ def _node_func(G):
 
     """
     if G.is_multigraph():
+
         def sorted_node(u, v, key):
             return (u, v, key) if u <= v else (v, u, key)
+
     else:
+
         def sorted_node(u, v):
             return (u, v) if u <= v else (v, u)
+
     return sorted_node
 
 
@@ -139,11 +130,15 @@ def _edge_func(G):
 
     """
     if G.is_multigraph():
+
         def get_edges(nbunch=None):
             return G.edges(nbunch, keys=True)
+
     else:
+
         def get_edges(nbunch=None):
             return G.edges(nbunch)
+
     return get_edges
 
 
@@ -224,7 +219,7 @@ def _lg_undirected(G, selfloops=False, create_using=None):
     # Determine if we include self-loops or not.
     shift = 0 if selfloops else 1
 
-    edges = set([])
+    edges = set()
     for u in G:
         # Label nodes as a sorted tuple of nodes in original graph.
         nodes = [sorted_node(*x) for x in get_edges(u)]
@@ -237,14 +232,14 @@ def _lg_undirected(G, selfloops=False, create_using=None):
         # especially important for multigraphs, we store the edges in
         # canonical form in a set.
         for i, a in enumerate(nodes):
-            edges.update([_sorted_edge(a, b) for b in nodes[i + shift:]])
+            edges.update([_sorted_edge(a, b) for b in nodes[i + shift :]])
 
     L.add_edges_from(edges)
     return L
 
 
-@not_implemented_for('directed')
-@not_implemented_for('multigraph')
+@not_implemented_for("directed")
+@not_implemented_for("multigraph")
 def inverse_line_graph(G):
     """ Returns the inverse line graph of graph G.
 
@@ -280,7 +275,7 @@ def inverse_line_graph(G):
     You should invert every component seperately:
 
     >>> K5 = nx.complete_graph(5)
-    >>> P4 = nx.Graph([('a', 'b'), ('b', 'c'), ('c', 'd')])
+    >>> P4 = nx.Graph([("a", "b"), ("b", "c"), ("c", "d")])
     >>> G = nx.union(K5, P4)
     >>> root_graphs = []
     >>> for comp in nx.connected_components(G):
@@ -303,7 +298,7 @@ def inverse_line_graph(G):
         v = list(G)[0]
         a = (v, 0)
         b = (v, 1)
-        H = nx.Graph([(a,b)])
+        H = nx.Graph([(a, b)])
         return H
     elif G.number_of_nodes() > 1 and G.number_of_edges() == 0:
         msg = (
@@ -321,8 +316,7 @@ def inverse_line_graph(G):
             P_count[u] += 1
 
     if max(P_count.values()) > 2:
-        msg = "G is not a line graph (vertex found in more " \
-              "than two partition cells)"
+        msg = "G is not a line graph (vertex found in more " "than two partition cells)"
         raise nx.NetworkXError(msg)
     W = tuple([(u,) for u in P_count if P_count[u] == 1])
     H = nx.Graph()
@@ -338,9 +332,9 @@ def _triangles(G, e):
     """ Return list of all triangles containing edge e"""
     u, v = e
     if u not in G:
-        raise nx.NetworkXError("Vertex %s not in graph" % u)
+        raise nx.NetworkXError(f"Vertex {u} not in graph")
     if v not in G[u]:
-        raise nx.NetworkXError("Edge (%s, %s) not in graph" % (u, v))
+        raise nx.NetworkXError(f"Edge ({u}, {v}) not in graph")
     triangle_list = []
     for x in G[u]:
         if x in G[v]:
@@ -375,10 +369,10 @@ def _odd_triangle(G, T):
     """
     for u in T:
         if u not in G.nodes():
-            raise nx.NetworkXError("Vertex %s not in graph" % u)
+            raise nx.NetworkXError(f"Vertex {u} not in graph")
     for e in list(combinations(T, 2)):
         if e[0] not in G[e[1]]:
-            raise nx.NetworkXError("Edge (%s, %s) not in graph" % (e[0], e[1]))
+            raise nx.NetworkXError(f"Edge ({e[0]}, {e[1]}) not in graph")
 
     T_neighbors = defaultdict(int)
     for t in T:
@@ -429,8 +423,10 @@ def _find_partition(G, starting_cell):
             for u in new_cell:
                 for v in new_cell:
                     if (u != v) and (v not in G_partition[u]):
-                        msg = "G is not a line graph" \
-                              "(partition cell not a complete subgraph)"
+                        msg = (
+                            "G is not a line graph"
+                            "(partition cell not a complete subgraph)"
+                        )
                         raise nx.NetworkXError(msg)
             P.append(tuple(new_cell))
             G_partition.remove_edges_from(list(combinations(new_cell, 2)))
@@ -467,8 +463,8 @@ def _select_starting_cell(G, starting_edge=None):
     else:
         e = starting_edge
         if e[0] not in G[e[1]]:
-            msg = 'starting_edge (%s, %s) is not in the Graph'
-            raise nx.NetworkXError(msg % e)
+            msg = f"starting_edge ({e[0]}, {e[1]}) is not in the Graph"
+            raise nx.NetworkXError(msg)
     e_triangles = _triangles(G, e)
     r = len(e_triangles)
     if r == 0:
@@ -504,7 +500,7 @@ def _select_starting_cell(G, starting_edge=None):
             # check if odd triangles containing e form complete subgraph
             # there must be exactly s+2 of them
             # and they must all be connected
-            triangle_nodes = set([])
+            triangle_nodes = set()
             for T in odd_triangles:
                 for x in T:
                     triangle_nodes.add(x)
@@ -512,17 +508,23 @@ def _select_starting_cell(G, starting_edge=None):
                 for u in triangle_nodes:
                     for v in triangle_nodes:
                         if u != v and (v not in G[u]):
-                            msg = "G is not a line graph (odd triangles " \
-                                  "do not form complete subgraph)"
+                            msg = (
+                                "G is not a line graph (odd triangles "
+                                "do not form complete subgraph)"
+                            )
                             raise nx.NetworkXError(msg)
                 # otherwise then we can use this as the starting cell
                 starting_cell = tuple(triangle_nodes)
             else:
-                msg = "G is not a line graph (odd triangles " \
-                      "do not form complete subgraph)"
+                msg = (
+                    "G is not a line graph (odd triangles "
+                    "do not form complete subgraph)"
+                )
                 raise nx.NetworkXError(msg)
         else:
-            msg = "G is not a line graph (incorrect number of " \
-                  "odd triangles around starting edge)"
+            msg = (
+                "G is not a line graph (incorrect number of "
+                "odd triangles around starting edge)"
+            )
             raise nx.NetworkXError(msg)
     return starting_cell
