@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#!/usr/bin/env python
 """
 ===========
 Erdos Renyi
@@ -12,16 +10,6 @@ This graph is sometimes called the Erdős-Rényi graph
 but is different from G{n,p} or binomial_graph which is also
 sometimes called the Erdős-Rényi graph.
 """
-# Author: Aric Hagberg (hagberg@lanl.gov)
-
-#    Copyright (C) 2004-2018 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-
-import sys
 
 import matplotlib.pyplot as plt
 from networkx import nx
@@ -34,13 +22,12 @@ G = nx.gnm_random_graph(n, m)
 # some properties
 print("node degree clustering")
 for v in nx.nodes(G):
-    print('%s %d %f' % (v, nx.degree(G, v), nx.clustering(G, v)))
+    print(f"{v} {nx.degree(G, v)} {nx.clustering(G, v)}")
 
-# print the adjacency list to terminal
-try:
-    nx.write_adjlist(G, sys.stdout)
-except TypeError:  # Python 3.x
-    nx.write_adjlist(G, sys.stdout.buffer)
+print()
+print("the adjacency list")
+for line in nx.generate_adjlist(G):
+    print(line)
 
 nx.draw(G)
 plt.show()
