@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """
 =====================
 Pygraphviz Attributes
@@ -10,22 +9,14 @@ AGraph class to convert to and from graphviz.
 Also see the pygraphviz documentation and examples at
 http://pygraphviz.github.io/
 """
-# Author: Aric Hagberg (hagberg@lanl.gov)
-
-#    Copyright (C) 2006-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
 
 import networkx as nx
 
 # networkx graph
 G = nx.Graph()
 # ad edges with red color
-G.add_edge(1, 2, color='red')
-G.add_edge(2, 3, color='red')
+G.add_edge(1, 2, color="red")
+G.add_edge(2, 3, color="red")
 # add nodes 3 and 4
 G.add_node(3)
 G.add_node(4)
@@ -34,7 +25,7 @@ G.add_node(4)
 A = nx.nx_agraph.to_agraph(G)
 
 # write to dot file
-A.write('k5_attributes.dot')
+A.write("k5_attributes.dot")
 
 # convert back to networkx Graph with attributes on edges and
 # default attributes as dictionary data
